@@ -5,13 +5,14 @@
  *
  * @package PhpMyAdmin
  */
+use PMA\libraries\Response;
 
 /**
  * Gets core libraries and defines some variables
  */
 require 'libraries/common.inc.php';
 
-$response = PMA\libraries\Response::getInstance();
+$response = Response::getInstance();
 $response->disable();
 $response->getHeader()->sendHttpHeaders();
 
@@ -35,10 +36,11 @@ if (@is_readable($filename)) {
 } else {
     printf(
         __(
-            'The %s file is not available on this system, please visit '
-            . 'www.phpmyadmin.net for more information.'
+            'The %s file is not available on this system, please visit ' .
+            '%s for more information.'
         ),
-        $filename
+        $filename,
+        '<a href="https://www.phpmyadmin.net/">phpmyadmin.net</a>'
     );
     exit;
 }
@@ -132,6 +134,9 @@ $replaces = array(
     '/(    ### )(.*)/'
     => '\\1<b>\\2</b>',
 
+    // Links target and rel
+    '/a href="/' => 'a target="_blank" rel="noopener noreferrer" href="'
+
 );
 
 header('Content-type: text/html; charset=utf-8');
@@ -151,12 +156,5 @@ echo '<pre>';
 echo preg_replace(array_keys($replaces), $replaces, $changelog);
 echo '</pre>';
 ?>
-<script type="text/javascript">
-var links = document.getElementsByTagName("a");
-for(var i = 0; i < links.length; i++) {
-    links[i].target = "_blank";
-    links[i].rel = "noopener noreferrer";
-}
-</script>
 </body>
 </html>
