@@ -64,6 +64,7 @@ var ErrorReport = {
             $('#error_report_dialog').remove();
         }
         var $div = $('<div id="error_report_dialog"></div>');
+        $div.css('z-index', '1000');
 
         var button_options = {};
 
@@ -303,8 +304,8 @@ var ErrorReport = {
 
 };
 
-TraceKit.report.subscribe(ErrorReport.error_handler);
-ErrorReport.set_up_error_reporting();
-$(function () {
+AJAX.registerOnload('error_report.js', function(){
+    TraceKit.report.subscribe(ErrorReport.error_handler);
+    ErrorReport.set_up_error_reporting();
     ErrorReport.wrap_global_functions();
 });
