@@ -14,6 +14,7 @@
 AJAX.registerTeardown('server_databases.js', function () {
     $(document).off('submit', "#dbStatsForm");
     $(document).off('submit', '#create_database_form.ajax');
+    $('#filterText').unbind('keyup');
 });
 
 /**
@@ -63,7 +64,10 @@ AJAX.registerOnload('server_databases.js', function () {
             function (url) {
                 PMA_ajaxShowMessage(PMA_messages.strProcessingRequest, false);
 
-                $.post(url, function (data) {
+                var params = getJSConfirmCommonParam(this);
+                params.token = PMA_commonParams.get('token');
+
+                $.post(url, params, function (data) {
                     if (typeof data !== 'undefined' && data.success === true) {
                         PMA_ajaxShowMessage(data.message);
 
@@ -130,4 +134,50 @@ AJAX.registerOnload('server_databases.js', function () {
             }
         }); // end $.post()
     }); // end $(document).on()
+
+    /* Don't show filter if number of databases are very few */
+    var databasesCount = $('#databases_count').html();
+    if(databasesCount <= 10) {
+        $('#tableFilter').hide();
+    }
+
+    var $filterField = $('#filterText');
+    /* Event handler for database filter */
+    $filterField.keyup(function (){
+       var textFilter = null, val = $(this).val();
+       if(val.length != 0) {
+           try {
+               textFilter = new RegExp(val.replace(/_/g, ' '), 'i');
+               $(this).removeClass('error');
+           } catch(e) {
+               if (e instanceof SyntaxError) {
+                   $(this).addClass('error');
+                   textFilter = null;
+               }
+           }
+       }
+       filterVariables(textFilter);
+    });
+
+    /* Trigger filtering of the list based on incoming database name */
+    if ($filterField.val()) {
+        $filterField.trigger('keyup').select();
+    }
+
+    /* Filters the rows by the user given regexp */
+    function filterVariables(textFilter) {
+        var $row, databasesCount = 0;
+        $('#tabledatabases').find('.db-row').each(function () {
+            $row = $(this);
+            if (textFilter === null ||
+                textFilter.exec($row.find('.name').text())
+               ) {
+                   $row.css('display', '');
+                   databasesCount += 1;
+               } else {
+                   $row.css('display', 'none');
+               }
+            $('#databases_count').html(databasesCount);
+        });
+    }
 }); // end $()
