@@ -5,8 +5,10 @@
  *
  * @package PhpMyAdmin
  */
+use PMA\libraries\Charsets;
 use PMA\libraries\Message;
 use PMA\libraries\Util;
+use PMA\libraries\URL;
 
 /**
  * Defines the central_columns parameters for the current user
@@ -380,7 +382,7 @@ function PMA_deleteColumnsFromList($field_select, $isTable=true)
 
     if (!$GLOBALS['dbi']->tryQuery($query, $GLOBALS['controllink'])) {
         $message = Message::error(__('Could not remove columns!'));
-        $message->addMessage('<br />' . htmlspecialchars($cols) . '<br />');
+        $message->addHtml('<br />' . htmlspecialchars($cols) . '<br />');
         $message->addMessage(
             Message::rawError(
                 $GLOBALS['dbi']->getError($GLOBALS['controllink'])
@@ -448,9 +450,9 @@ function PMA_makeConsistentWithList($db, $selected_tables)
                     $GLOBALS['dbi']->getError($GLOBALS['userlink'])
                 );
             } else {
-                $message->addMessage('<br />');
-                $message->addMessage(
-                    $GLOBALS['dbi']->getError($GLOBALS['userlink'])
+                $message->addText(
+                    $GLOBALS['dbi']->getError($GLOBALS['userlink']),
+                    '<br />'
                 );
             }
         }
@@ -613,7 +615,7 @@ function PMA_getHTMLforTableNavigation($total_rows, $pos, $db)
     if ($pos - $max_rows >= 0) {
         $table_navigation_html .= '<td>'
             . '<form action="db_central_columns.php" method="post">'
-            . PMA_URL_getHiddenInputs(
+            . URL::getHiddenInputs(
                 $db
             )
             . '<input type="hidden" name="pos" value="' . ($pos - $max_rows) . '" />'
@@ -628,7 +630,7 @@ function PMA_getHTMLforTableNavigation($total_rows, $pos, $db)
         $table_navigation_html .= '<td>';
         $table_navigation_html .= '<form action="db_central_columns.php'
             . '" method="post">'
-            . PMA_URL_getHiddenInputs(
+            . URL::getHiddenInputs(
                 $db
             )
             . '<input type="hidden" name="total_rows" value="' . $total_rows . '"/>';
@@ -641,7 +643,7 @@ function PMA_getHTMLforTableNavigation($total_rows, $pos, $db)
     if ($pos + $max_rows < $total_rows) {
         $table_navigation_html .= '<td>'
             . '<form action="db_central_columns.php" method="post">'
-            . PMA_URL_getHiddenInputs(
+            . URL::getHiddenInputs(
                 $db
             )
             . '<input type="hidden" name="pos" value="' . ($pos + $max_rows) . '" />'
@@ -801,7 +803,7 @@ function PMA_getHTMLforAddCentralColumn($total_rows, $pos, $db)
             __('Add column')
         )
         . '<form id="add_column" action="db_central_columns.php" method="post">'
-        . PMA_URL_getHiddenInputs(
+        . URL::getHiddenInputs(
             $db
         )
         . '<input type="hidden" name="add_column" value="add">'
@@ -825,17 +827,15 @@ function PMA_getHTMLforAddCentralColumn($total_rows, $pos, $db)
  *
  * @param array   $row     array contains complete information of
  * a particular row of central list table
- * @param boolean $odd_row set true if the row is at odd number position
  * @param int     $row_num position the row in the table
  * @param string  $db      current database
  *
  * @return string html of a particular row in the central columns table.
  */
-function PMA_getHTMLforCentralColumnsTableRow($row, $odd_row, $row_num, $db)
+function PMA_getHTMLforCentralColumnsTableRow($row, $row_num, $db)
 {
-    $tableHtml = '<tr data-rownum="' . $row_num . '" id="f_' . $row_num . '" '
-        . 'class="' . ($odd_row ? 'odd' : 'even') . '">'
-        . PMA_URL_getHiddenInputs(
+    $tableHtml = '<tr data-rownum="' . $row_num . '" id="f_' . $row_num . '">'
+        . URL::getHiddenInputs(
             $db
         )
         . '<input type="hidden" name="edit_save" value="save">'
@@ -935,8 +935,8 @@ function PMA_getHTMLforCentralColumnsTableRow($row, $odd_row, $row_num, $db)
     $tableHtml .=
         '<td name="collation" class="nowrap">'
         . '<span>' . htmlspecialchars($row['col_collation']) . '</span>'
-        . PMA_generateCharsetDropdownBox(
-            PMA_CSDROPDOWN_COLLATION, 'field_collation[' . $row_num . ']',
+        . Charsets::getCollationDropdownBox(
+            'field_collation[' . $row_num . ']',
             'field_' . $row_num . '_4', $row['col_collation'], false
         )
         . '</td>';
@@ -998,14 +998,13 @@ function PMA_getHTMLforCentralColumnsTableRow($row, $odd_row, $row_num, $db)
  *
  * @param array   $row     array contains complete information of
  * a particular row of central list table
- * @param boolean $odd_row set true if the row is at odd number position
  * @param int     $row_num position the row in the table
  *
  * @return string html of a particular row in the central columns table.
  */
-function PMA_getHTMLforCentralColumnsEditTableRow($row, $odd_row, $row_num)
+function PMA_getHTMLforCentralColumnsEditTableRow($row, $row_num)
 {
-    $tableHtml = '<tr class="' . ($odd_row ? 'odd' : 'even') . '">'
+    $tableHtml = '<tr>'
         . '<input name="orig_col_name[' . $row_num . ']" type="hidden" '
         . 'value="' . htmlspecialchars($row['col_name']) . '">'
         . '<td name="col_name" class="nowrap">'
@@ -1077,8 +1076,8 @@ function PMA_getHTMLforCentralColumnsEditTableRow($row, $odd_row, $row_num)
         . '</td>';
     $tableHtml .=
         '<td name="collation" class="nowrap">'
-        . PMA_generateCharsetDropdownBox(
-            PMA_CSDROPDOWN_COLLATION, 'field_collation[' . $row_num . ']',
+        . Charsets::getCollationDropdownBox(
+            'field_collation[' . $row_num . ']',
             'field_' . $row_num . '_4', $row['col_collation'], false
         )
         . '</td>';
@@ -1183,16 +1182,20 @@ function PMA_getCentralColumnsListRaw($db, $table)
  */
 function PMA_getCentralColumnsTableFooter($pmaThemeImage, $text_dir)
 {
-    $html_output = Util::getWithSelected(
-        $pmaThemeImage, $text_dir, "tableslistcontainer"
-    );
+    $html_output = PMA\libraries\Template::get('select_all')
+        ->render(
+            array(
+                'pmaThemeImage' => $pmaThemeImage,
+                'text_dir'      => $text_dir,
+                'formName'      => 'tableslistcontainer',
+            )
+        );
     $html_output .= Util::getButtonOrImage(
         'edit_central_columns', 'mult_submit change_central_columns',
-        'submit_mult_change', __('Edit'), 'b_edit.png', 'edit central columns'
+        __('Edit'), 'b_edit.png', 'edit central columns'
     );
     $html_output .= Util::getButtonOrImage(
         'delete_central_columns', 'mult_submit',
-        'submit_mult_central_columns_remove',
         __('Delete'), 'b_drop.png',
         'remove_from_central_columns'
     );
@@ -1249,18 +1252,20 @@ function PMA_handleColumnExtra(&$columns_list)
 /**
  * build html for adding a new user defined column to central list
  *
- * @param string $db current database
+ * @param string  $db         current database
+ * @param integer $total_rows number of rows in central columns
  *
  * @return string html of the form to let user add a new user defined column to the
  *                list
  */
-function PMA_getHTMLforAddNewColumn($db)
+function PMA_getHTMLforAddNewColumn($db, $total_rows)
 {
-    $addNewColumn = '<div id="add_col_div"><a href="#">'
+    $addNewColumn = '<div id="add_col_div" class="topmargin"><a href="#">'
         . '<span>+</span> ' . __('Add new column') . '</a>'
-        . '<form id="add_new" style="min-width:100%;display:none" '
+        . '<form id="add_new" class="new_central_col '
+        . ($total_rows != 0 ? 'hide"' : '"')
         . 'method="post" action="db_central_columns.php">'
-        . PMA_URL_getHiddenInputs(
+        . URL::getHiddenInputs(
             $db
         )
         . '<input type="hidden" name="add_new_column" value="add_new_column">'
@@ -1318,8 +1323,8 @@ function PMA_getHTMLforAddNewColumn($db)
             )
         . '</td>'
         . '<td name="collation" class="nowrap">'
-        . PMA_generateCharsetDropdownBox(
-            PMA_CSDROPDOWN_COLLATION, 'field_collation[0]',
+        . Charsets::getCollationDropdownBox(
+            'field_collation[0]',
             'field_0_4', null, false
         )
         . '</td>'
@@ -1388,14 +1393,12 @@ function PMA_getHTMLforEditingPage($selected_fld,$selected_db)
     $columns_list = implode("','", $selected_fld_safe);
     $columns_list = "'" . $columns_list . "'";
     $list_detail_cols = PMA_findExistingColNames($selected_db, $columns_list, true);
-    $odd_row = false;
     $row_num = 0;
     foreach ($list_detail_cols as $row) {
         $tableHtmlRow = PMA_getHTMLforCentralColumnsEditTableRow(
-            $row, $odd_row, $row_num
+            $row, $row_num
         );
         $html .= $tableHtmlRow;
-        $odd_row = !$odd_row;
         $row_num++;
     }
     $html .= '</table>';
