@@ -222,17 +222,18 @@ function PMA_fatalError($error_message, $message_args = null) {
     }
 
     /*
-     * Avoid using Response if Config is not yet loaded
+     * Avoid using Response class as config does not have to be loaded yet
      * (this can happen on early fatal error)
      */
-    if (isset($GLOBALS['Config'])) {
-        $response = Response::getInstance();
-    } else {
-        $response = null;
-    }
-    if (! is_null($response) && $response->isAjax()) {
-        $response->setRequestStatus(false);
-        $response->addJSON('message', PMA\libraries\Message::error($error_message));
+    if (! empty($_REQUEST['ajax_request'])) {
+        // Generate JSON manually
+        PMA_headerJSON();
+        echo json_encode(
+            array(
+                'success' => false,
+                'error' => Message::error($error_message)->getDisplay(),
+            )
+        );
     } else {
         $error_message = strtr($error_message, array('<br />' => '[br]'));
 
