@@ -18,10 +18,6 @@ if (!defined('PHPMYADMIN')) {
 require_once './libraries/config/FormDisplay.tpl.php';
 require_once './setup/lib/index.lib.php';
 
-$config_readable = false;
-$config_writable = false;
-$config_exists = false;
-PMA_checkConfigRw($config_readable, $config_writable, $config_exists);
 echo '<h2>' , __('Configuration file') , '</h2>';
 
 echo PMA_displayFormTop('config.php');
@@ -40,11 +36,6 @@ echo '<tr>';
 echo '<td class="lastrow" style="text-align: left">';
 echo '<input type="submit" name="submit_download" value="'
     , __('Download') , '" class="green" />';
-echo '<input type="submit" name="submit_save" value="' , __('Save') , '"';
-if (!$config_writable) {
-    echo ' disabled="disabled"';
-}
-echo '/>';
 echo '</td>';
 echo '</tr>';
 
