@@ -8,6 +8,7 @@
  *
  * @package PhpMyAdmin
  */
+use PMA\libraries\Response;
 
 /**
  * Gets some core libraries
@@ -23,7 +24,7 @@ $container->factory('PMA\libraries\controllers\table\TableSearchController');
 $container->alias(
     'TableSearchController', 'PMA\libraries\controllers\table\TableSearchController'
 );
-$container->set('PMA\libraries\Response', PMA\libraries\Response::getInstance());
+$container->set('PMA\libraries\Response', Response::getInstance());
 $container->alias('response', 'PMA\libraries\Response');
 
 /* Define dependencies for the concerned controller */
