@@ -7,6 +7,8 @@
  * @todo (also validate if js is disabled, after form submission?)
  * @package PhpMyAdmin
  */
+use PMA\libraries\URL;
+use PMA\libraries\Response;
 
 require_once './libraries/common.inc.php';
 
@@ -17,6 +19,8 @@ require './libraries/db_common.inc.php';
 $url_params['goto'] = 'tbl_structure.php';
 $url_params['back'] = 'view_create.php';
 
+$response = Response::getInstance();
+
 $view_algorithm_options = array(
     'UNDEFINED',
     'MERGE',
@@ -37,6 +41,19 @@ if (empty($sql_query)) {
     $sql_query = '';
 }
 
+// View name is a compulsory field
+if (isset($_REQUEST['view']['name'])
+    && empty($_REQUEST['view']['name'])
+) {
+    $message = PMA\libraries\Message::error(__('View name can not be empty!'));
+    $response->addJSON(
+        'message',
+        $message
+    );
+    $response->setRequestStatus(false);
+    exit;
+}
+
 if (isset($_REQUEST['createview']) || isset($_REQUEST['alterview'])) {
     /**
      * Creates the view
@@ -57,9 +74,14 @@ if (isset($_REQUEST['createview']) || isset($_REQUEST['alterview'])) {
     }
 
     if (! empty($_REQUEST['view']['definer'])) {
-        $arr = explode('@', $_REQUEST['view']['definer']);
-        $sql_query .= $sep . 'DEFINER=' . PMA\libraries\Util::backquote($arr[0]);
-        $sql_query .= '@' . PMA\libraries\Util::backquote($arr[1]) . ' ';
+        if (strpos($_REQUEST['view']['definer'], '@') === FALSE) {
+            $sql_query .= $sep . 'DEFINER='
+                . PMA\libraries\Util::backquote($_REQUEST['view']['definer']);
+        } else {
+            $arr = explode('@', $_REQUEST['view']['definer']);
+            $sql_query .= $sep . 'DEFINER=' . PMA\libraries\Util::backquote($arr[0]);
+            $sql_query .= '@' . PMA\libraries\Util::backquote($arr[1]) . ' ';
+        }
     }
 
     if (isset($_REQUEST['view']['sql_security'])) {
@@ -91,7 +113,6 @@ if (isset($_REQUEST['createview']) || isset($_REQUEST['alterview'])) {
             return;
         }
 
-        $response = PMA\libraries\Response::getInstance();
         $response->addJSON(
             'message',
             PMA\libraries\Message::error(
@@ -138,7 +159,6 @@ if (isset($_REQUEST['createview']) || isset($_REQUEST['alterview'])) {
         $message = PMA\libraries\Message::success();
         include 'tbl_structure.php';
     } else {
-        $response = PMA\libraries\Response::getInstance();
         $response->addJSON(
             'message',
             PMA\libraries\Util::getMessage(
@@ -178,7 +198,7 @@ $url_params['reload'] = 1;
 $htmlString = '<!-- CREATE VIEW options -->'
     . '<div id="div_view_options">'
     . '<form method="post" action="view_create.php">'
-    . PMA_URL_getHiddenInputs($url_params)
+    . URL::getHiddenInputs($url_params)
     . '<fieldset>'
     . '<legend>'
     . (isset($_REQUEST['ajax_dialog']) ?
